@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.3.1
+# @version 2.4.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -168,6 +168,16 @@ library, use the same compiler you're using here."""
             sys.exit()
         print "done"
 
+        log = log+output+error
+
+        comm = self.config.ranlib+" librefblas.a"
+        (output, error, retz) = runShellCommand(comm)
+        if retz:
+            print "\n\nBLAS: cannot create table of contents for blas library"
+            print "stderr:\n","*"*40,"\n",comm,'\n',error,"\n","*"*40
+            sys.exit()
+        print "done"
+        
         # write the log on a file
         log = log+output+error
         fulllog = os.path.join(savecwd,'log/blaslog')
