@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.3.1
+# @version 2.4.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -43,7 +43,7 @@ class Framework:
     plasmalib    = ""                        # plasma library
     plasmaurl    = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs/plasma.tar.gz"
     urlbase      = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs"
-    versions     = ("2.3.1", "2.3.0", "2.2.0", "2.1.0", "2.0.0", "1.0.1", "1.0.0")
+    versions     = ("2.4.1", "2.4.0", "2.3.1", "2.3.0", "2.2.0", "2.1.0", "2.0.0", "1.0.1", "1.0.0")
     oldversions  = ("2.1.0", "2.0.0", "1.0.1", "1.0.0") # Releases from version which need the internal cblas and lapack
     ranlib       = ""                        # the ranlib command
     clean        = 0
@@ -127,7 +127,7 @@ You can specify it using the --fc flag."""
             print 'CBLAS library is... REFERENCE CBLAS ( To download )'
         elif (self.config.cblaslib == ""):
             if (self.downcblas == 1):
-                print 'CBLAS library is... Check if included in Blas Library and dowload if it is not'
+                print 'CBLAS library is... Check if included in Blas Library and download if it is not'
             else:
                 print 'CBLAS library is... Check if included in Blas Library'
         else :
@@ -137,7 +137,7 @@ You can specify it using the --fc flag."""
             print 'LAPACK library is... REFERENCE LAPACK ( To download )'
         elif (self.config.lapacklib == ""):
             if (self.downlapack == 1):
-                print 'LAPACK library is... Check if included in Blas Library and dowload if it is not'
+                print 'LAPACK library is... Check if included in Blas Library and download if it is not'
             else:
                 print 'LAPACK library is... Check if included in Blas library'
         else:
@@ -147,7 +147,7 @@ You can specify it using the --fc flag."""
             print 'LAPACK C Interface library is... REFERENCE LAPACKE INTERFACE ( To download )'
         elif (self.config.lapclib == ""):
             if (self.downlapc == 1):
-                print 'LAPACKE Interface is... Check if included in Blas Library and dowload if it is not'
+                print 'LAPACKE Interface is... Check if included in Blas Library and download if it is not'
             else:
                 print 'LAPACKE Interface library is... Check if included in Lapack library'
         else:
@@ -583,7 +583,7 @@ You can specify it using the --fc flag."""
             if wget:
                 # test wget
                 print "Testing wget...",
-                comm = 'wget http://www.netlib.org/lapack/index'
+                comm = 'wget --tries=2 --timeout=5 http://www.netlib.org/lapack/index'
                 (output, error, retz) = runShellCommand(comm)
                 if(retz != 0):
                     print 'not working.'
@@ -795,13 +795,16 @@ You can specify it using the --fc flag."""
 
 Installation of all librairies required by PLASMA is completed.
 
-You can copy the foolowing file in your src directory to compile PLASMA :\n"""+os.path.join(self.build,'make.inc')+"""\n
+You can copy the following file in your src directory to compile
+PLASMA :\n"""+os.path.join(self.build,'make.inc')+"""\n
 
-WARNING: the prefix directory has been set to same directory than external libraies.
-If you want to install PLASMA in another directory, don't forget to change it.
+WARNING: the prefix directory has been set to same directory than
+external libraies.  If you want to install PLASMA in another
+directory, don't forget to change it.
 
-We strongly recommend the use of hwloc library for a better binding of the threads.
-It will be automatically detected if pkg-config is set to find it.
+We strongly recommend the use of hwloc library for a better binding of
+the threads.  It will be automatically detected if pkg-config is set
+to find it.
 
 Log messages are in the\n"""+os.path.join(self.build,'log')+"""
 directory.
@@ -810,9 +813,8 @@ The\n"""+self.build+"""/downloads
 directory contains all tarballs of downloaded librairies.
 
 The\n"""+self.build+"""
-directory contains the source code of the libraries
-that have been installed. It can be removed once you have copy the
-make.inc file.
+directory contains the source code of the libraries that have been
+installed. It can be removed once you have copy the make.inc file.
 
 ******************************************************
 ******************************************************
@@ -845,6 +847,9 @@ directory contains the source code of the libraries
 that have been installed. It can be removed at this time.
 
 ******************************************************
+WARNING: the following environment variables have been 
+  set to 1:
+  OMP_NUM_THREADS, GOTO_NUM_THREADS, MKL_NUM_THREADS
 ******************************************************
 """
         return 0
