@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.3.1
+# @version 2.4.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -27,7 +27,7 @@ class Lapack(framework.Framework):
     """ This class takes care of the LAPACK installation. """
     def __init__(self, config, plasma):
         print "\n","="*40
-        print "  Lapack installation/verification"
+        print "  LAPACK installation/verification"
         print "="*40
 
         self.config     = config
@@ -63,7 +63,6 @@ netlib.
 The LAPACK library is not needed in the case where testing is disabled
 by means of the --notesting flag.
 
-
 What do you want to do ?
     - d : download the netlib LAPACK
     - q : quit and try with another BLAS library or define the
@@ -208,19 +207,19 @@ The reference LAPACK library is being installed.
 
 #         # Overwrite [sd]lamch.f
 #         shutil.copy(os.path.join(self.plasma.installerdir,'src/dlamch.f'),
-#                     os.path.join(os.getcwd(),'lapack-3.3.0/INSTALL'))
+#                     os.path.join(os.getcwd(),'lapack-3.3.1/INSTALL'))
 #         shutil.copy(os.path.join(self.plasma.installerdir,'src/slamch.f'),
-#                     os.path.join(os.getcwd(),'lapack-3.3.0/INSTALL'))
+#                     os.path.join(os.getcwd(),'lapack-3.3.1/INSTALL'))
 
         # change to BLAS dir
-        os.chdir(os.path.join(os.getcwd(),'lapack-3.3.0'))
+        os.chdir(os.path.join(os.getcwd(),'lapack-3.3.1'))
 
         # Write Makefile.in
         writefile('make.inc', """
 # -*- Makefile -*-
 ####################################################################
 #  LAPACK make include file.                                       #
-#  LAPACK, Version 3.3.0                                           #
+#  LAPACK, Version 3.3.1                                           #
 #  April 2009                                                      #
 ####################################################################
 #
