@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.3.1
+# @version 2.4.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -22,7 +22,7 @@ import shutil
 import framework
 
 class Lapcwrapper(framework.Framework):
-    lapcurl     = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs/lapacke.tgz"
+    lapcurl     = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs/lapacke-3.3.0.tgz"
 
     """ This class takes care of the LAPACK C interface installation. """
     def __init__(self, config, plasma):
@@ -50,9 +50,6 @@ Please provide a working LAPACK C interface. If a LAPACK C interface is not
 present on the system, the netlib LAPACK C interface can be automatically
 downloaded and installed by adding the --downlapc flag.
 
-The LAPACK C interface is not needed in the case where testing is disabled
-by means of the --notesting flag.
-
 What do you want to do ?
     - d : download automatically the netlib LAPACK C interface
     - q : quit to download and install manually a LAPACK C interface.
@@ -145,20 +142,20 @@ The reference LAPACK C interface is being installed.
 
         # unzip and untar
         print 'Unzip and untar reference LAPACK C interface...',
-        comm = 'gunzip -f lapacke.tgz'
+        comm = 'gunzip -f lapacke-3.3.0.tgz'
         (output, error, retz) = runShellCommand(comm)
         if retz:
             print '\n\nLAPCWRAPPER: cannot unzip lapacke.tgz'
             print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
             sys.exit()
 
-        comm = 'tar xf lapacke.tar'
+        comm = 'tar xf lapacke-3.3.0.tar'
         (output, error, retz) = runShellCommand(comm)
         if retz:
             print '\n\nLAPCWRAPPER: cannot untar lapacke.tar'
             print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
             sys.exit()
-        os.remove('lapacke.tar')
+        os.remove('lapacke-3.3.0.tar')
         print 'done'
 
         # change to LAPACK C interface dir
