@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.3.1
+# @version 2.4.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -28,7 +28,7 @@ class Plasma(framework.Framework):
 
     def resume(self):
         print '\n','='*40
-        print 'Plasma installer is starting now. Buckle up!'
+        print '  PLASMA installer is starting now. Buckle up!'
         print '='*40
 
         if self.src:
@@ -40,7 +40,7 @@ class Plasma(framework.Framework):
         framework.Framework.resume(self)
 
     def write_makeinc(self):
-        """ Writes the make.inc file for Plasma installation """
+        """ Writes the make.inc file for PLASMA installation """
 
         sdir = os.getcwd()
         print 'Writing make.inc...',
@@ -167,7 +167,7 @@ LIBCLAPACK  = """+self.config.lapclib+"""
         comm = "gunzip -f " + cur_fname
         (output, error, retz) = runShellCommand(comm)
         if retz:
-            print "\n\nPlasma: cannot unzip " + cur_fname
+            print "\n\nPLASMA: cannot unzip " + cur_fname
             print "stderr:\n",'*'*40,'\n',error,'\n','*'*40
             sys.exit()
 
@@ -207,7 +207,7 @@ LIBCLAPACK  = """+self.config.lapclib+"""
 
         liblog = os.path.join(savecwd,'log/plasmalog')
         writefile(liblog, output+error)
-        print 'Installation of PLASMA successful..'
+        print 'Installation of PLASMA successful.'
         print '(log is in ',liblog,')'
 
         # Testings
@@ -270,7 +270,7 @@ LIBCLAPACK  = """+self.config.lapclib+"""
             os.chdir(os.path.join(os.getcwd(),'../..'))
 
         # Install
-        print '--- Install Plasma ---',
+        print '--- Install PLASMA ---',
         sys.stdout.flush()
         if (self.version in self.oldversions) :
             shutil.copy('lib/libplasma.a',    os.path.join(self.prefix,'lib/libplasma.a'))
